# Temporary Mail
```python
$ pip install xtempmail
```

# Feature
<ul>
<li>Custom Name/Mail</li>
<li>Reply/send Message(support attachment file)</li>
<li>Read Message (support Download attachemnt file)</li>
<li> Delete message</li>
<li>Destroy Inbox</li>
</ul>

# Example
```
example/main.py
```